/**
 * WordPress dependencies
 */
import { __ } from '@wordpress/i18n';
import { CheckboxControl } from '@wordpress/components';
import { compose } from '@wordpress/compose';
import { withDispatch, withSelect } from '@wordpress/data';
import { Fragment } from '@wordpress/element';

/**
 * Internal dependencies
 */
import DisplayPlayerCheck from './check';

export function DisplayPlayer( {
	displayPlayer,
	onUpdateDisplayPlayer,
	wrapper,
} ) {
	const Wrapper = wrapper || Fragment;
	return (
		<DisplayPlayerCheck>
			<Wrapper>
				<CheckboxControl
					label={ __( 'Display Player', 'speechkit' ) }
					checked={ displayPlayer }
					onChange={ () => { onUpdateDisplayPlayer( ! displayPlayer ) } }
				/>
			</Wrapper>
		</DisplayPlayerCheck>
	);
}

export default compose( [
	withSelect( ( select ) => {
		const { getEditedPostAttribute } = select( 'core/editor' );
		return {
			displayPlayer: getEditedPostAttribute('meta').speechkit_disabled !== '1',
		}
	} ),
	withDispatch( ( dispatch ) => {
		const { editPost } = dispatch( 'core/editor' );
		return {
			onUpdateDisplayPlayer: ( displayPlayer ) => {
				editPost( {
					meta: {
						speechkit_disabled: displayPlayer ? '' : '1',
					},
				} );
			},
		};
	} ),
] )( DisplayPlayer );
