/**
 * WordPress dependencies
 */
import { __ } from '@wordpress/i18n';
import { PanelBody, TextareaControl, TextControl } from '@wordpress/components';
import { compose } from '@wordpress/compose';
import { withSelect } from '@wordpress/data';

export function PostInspectPanel( {
	publishPostToSpeechkit,
	disabled,
	error,
	info,
	podcastId,
	projectId,
	response,
	retries,
	status,
	link,
	text,
} ) {
	return (
		<PanelBody
			title={ __( 'Inspect', 'speechkit' ) }
			initialOpen={ false }
			className={ 'speechkit speechkit-sidebar__inspect' }
		>
			<TextControl
				label="publish_post_to_speechkit"
				readOnly
				value={ publishPostToSpeechkit }
			/>
			<TextControl
				label="speechkit_disabled"
				readOnly
				value={ disabled }
			/>
			{ /* eslint-disable-next-line prettier/prettier */ }
			<TextareaControl
				label="speechkit_error"
				readOnly
				rows="3"
				value={ error }
			/>
			<TextareaControl
				label="speechkit_info"
				readOnly
				rows="3"
				value={ info }
			/>
			<TextControl
				label="speechkit_podcast_id"
				readOnly
				value={ podcastId }
			/>
			<TextControl
				label="speechkit_project_id"
				readOnly
				value={ projectId }
			/>
			{ /* eslint-disable-next-line prettier/prettier */ }
			<TextareaControl
				label="speechkit_response"
				readOnly
				rows="3"
				value={ response }
			/>
			{ /* eslint-disable-next-line prettier/prettier */ }
			<TextControl
				label="speechkit_retries"
				readOnly
				value={ retries }
			/>
			{ /* eslint-disable-next-line prettier/prettier */ }
			<TextControl
				label="speechkit_status"
				readOnly
				value={ status }
			/>
			{ /* eslint-disable-next-line prettier/prettier */ }
			<TextControl
				label="_speechkit_link"
				readOnly
				value={ link }
			/>
			<TextareaControl
				label="_speechkit_text"
				readOnly
				rows="3"
				value={ text }
			/>
		</PanelBody>
	);
}

export default compose( [
	withSelect( ( select ) => {
		const { getEditedPostAttribute } = select( 'core/editor' );

		return {
			publishPostToSpeechkit: getEditedPostAttribute( 'meta' )
				.publish_post_to_speechkit,
			disabled: getEditedPostAttribute( 'meta' ).speechkit_disabled,
			error: getEditedPostAttribute( 'meta' ).speechkit_error,
			info: getEditedPostAttribute( 'meta' ).speechkit_info,
			podcastId: getEditedPostAttribute( 'meta' ).speechkit_podcast_id,
			projectId: getEditedPostAttribute( 'meta' ).speechkit_project_id,
			response: getEditedPostAttribute( 'meta' ).speechkit_response,
			retries: getEditedPostAttribute( 'meta' ).speechkit_retries,
			status: getEditedPostAttribute( 'meta' ).speechkit_status,
			link: getEditedPostAttribute( 'meta' )._speechkit_link,
			text: getEditedPostAttribute( 'meta' )._speechkit_text,
		};
	} ),
] )( PostInspectPanel );
