/**
 * WordPress dependencies
 */
import { __ } from '@wordpress/i18n';
import { FocusableIframe } from '@wordpress/components';
import { compose } from '@wordpress/compose';
import { withSelect } from '@wordpress/data';
import { Fragment } from '@wordpress/element';

/**
 * Internal dependencies
 */
import PlayAudioCheck from './check';

export function PlayAudio( { src, isScheduled, wrapper = Fragment } ) {
	const Wrapper = wrapper;

	return (
		<PlayAudioCheck>
			<Wrapper>
				<FocusableIframe
					style={ { height: '60px', overflow: 'hidden' } }
					src={ src }
				/>
			</Wrapper>
			{ isScheduled && (
				<Wrapper>
					{ __(
						'Audio for posts with a future publish date is currently unavailable to preview. We’re working on this!',
						'speechkit'
					) }
				</Wrapper>
			) }
		</PlayAudioCheck>
	);
}

export default compose( [
	withSelect( ( select ) => {
		const {
			getEditedPostAttribute,
			isCurrentPostScheduled,
			isEditedPostBeingScheduled,
		} = select( 'core/editor' );
		return {
			isScheduled: isCurrentPostScheduled() || isEditedPostBeingScheduled(),
			src: getEditedPostAttribute( 'meta' )._speechkit_link,
		};
	} ),
] )( PlayAudio );
