/**
 * WordPress dependencies
 */
import { __ } from '@wordpress/i18n';
import { PanelBody, PanelRow, ToggleControl } from '@wordpress/components';
import { compose } from '@wordpress/compose';
import { withDispatch, withSelect } from '@wordpress/data';

const panel = ( props ) => (
	<PanelBody title={ __( 'SpeechKit', 'speechkit' ) } initialOpen={ true }>
		<PanelRow>
			<ToggleControl
				label={ __( 'Generate Audio', 'speechkit' ) }
				checked={ props.generateAudio }
				onChange={ ( value ) => {
					props.onGenerateAudioChange( value );
				} }
			/>
		</PanelRow>
	</PanelBody>
);

export default compose(
	withSelect( ( select ) => {
		const { getEditedPostAttribute } = select( 'core/editor' );
		return {
			generateAudio:
				// The default value is checked, so look for anything other than unchecked ('0')
				getEditedPostAttribute( 'meta' ).publish_post_to_speechkit !== '0',
		};
	} ),
	withDispatch( ( dispatch ) => {
		const { editPost } = dispatch( 'core/editor' );
		return {
			onGenerateAudioChange: ( value ) => {
				editPost( {
					meta: { publish_post_to_speechkit: value ? '1' : '0' },
				} );
			},
		};
	} )
)( panel );
