/* global ajaxurl */

/**
 * WordPress dependencies
 */
import { __ } from '@wordpress/i18n';
import { Button, Dashicon } from '@wordpress/components';
import { compose } from '@wordpress/compose';
import { withDispatch, withSelect } from '@wordpress/data';
import { Fragment } from '@wordpress/element';

/**
 * Internal dependencies
 */
import * as SPEECHKIT_STATUS from '../../constants/speechkit-status';
import RegerateAudioCheck from './check';

export function RegenerateAudio( props ) {
	const {
		createRegenerateErrorNotice,
		isRegeneratingAudio,
		postId,
		setSpeechkitStatus,
		setIsRegeneratingAudio,
		wrapper = Fragment,
	} = props;

	const Wrapper = wrapper;

	const callApi = function () {
		setIsRegeneratingAudio( true );

		window
			.fetch( ajaxurl, {
				method: 'POST',
				mode: 'same-origin',
				body: new URLSearchParams( {
					post_id: postId,
					action: 'sk_regenerate',
				} ),
			} )
			.then( ( res ) => {
				setIsRegeneratingAudio( false );

				if ( res.status === 200 ) {
					setSpeechkitStatus( SPEECHKIT_STATUS.UPDATED );
				} else {
					createRegenerateErrorNotice();
				}
			} );
	};

	return (
		<RegerateAudioCheck>
			<Wrapper>
				<Button
					isSecondary
					onClick={ callApi }
					disabled={ isRegeneratingAudio }
					isBusy={ isRegeneratingAudio }
				>
					<Dashicon icon="update" />{ ' ' }
					{ __( 'Regenerate Audio', 'speechkit' ) }
				</Button>
			</Wrapper>
		</RegerateAudioCheck>
	);
}

export default compose( [
	withSelect( ( select ) => {
		const { getEditedPostAttribute } = select( 'core/editor' );
		const { getIsRegeneratingAudio } = select( 'speechkit/settings' );
		return {
			isRegeneratingAudio: getIsRegeneratingAudio(),
			postId: getEditedPostAttribute( 'id' ),
		};
	} ),
	withDispatch( ( dispatch ) => {
		const { editPost } = dispatch( 'core/editor' );
		const { createNotice } = dispatch( 'core/notices' );
		const { setIsRegeneratingAudio } = dispatch( 'speechkit/settings' );
		return {
			setSpeechkitStatus: ( status ) => {
				editPost( {
					meta: {
						speechkit_status: status,
					},
				} );
			},
			setIsRegeneratingAudio: ( value ) => {
				setIsRegeneratingAudio( value );
			},
			createRegenerateErrorNotice: () => {
				createNotice(
					'error',
					__(
						// eslint-disable-next-line max-len
						'Sorry, but SpeechKit was unable to regenerate the audio. Please try again, and email our support team if the problem persists.',
						'speechkit'
					),
					{
						isDismissible: true,
						actions: [
							{
								label: __( 'Email SpeechKit', 'speechkit' ),
								url:
									'mailto:support@speechkit.io?subject=Error: Regenerate Audio',
							},
						],
					}
				);
			},
		};
	} ),
] )( RegenerateAudio );
