/**
 * WordPress dependencies
 */
import { compose } from '@wordpress/compose';
import { withSelect } from '@wordpress/data';

/**
 * Internal dependencies
 */
import * as SPEECHKIT_STATUS from '../../constants/speechkit-status';

export function StatusSpinnerCheck( { hasStatusSpinnerAction, children } ) {
	if ( ! hasStatusSpinnerAction ) {
		return null;
	}

	return children;
}

export default compose( [
	withSelect( ( select ) => {
		const { getEditedPostAttribute } = select( 'core/editor' );
		const validStatuses = [
			SPEECHKIT_STATUS.NEW,
			SPEECHKIT_STATUS.UPDATED,
			SPEECHKIT_STATUS.PROCESSING,
		];
		return {
			hasStatusSpinnerAction: validStatuses.includes(
				getEditedPostAttribute( 'meta' ).speechkit_status
			),
		};
	} ),
] )( StatusSpinnerCheck );
