<?php

$post_status = get_post_meta(get_the_ID(), 'speechkit_status', true);

// hotfix v2.9.5
// Update existing posts that have status + error message for the "out of credits" response
if ($post_status === Speechkit_Admin::STATUS_FAILED . __(' - You\'ve exceeded your audio quota. Please upgrade plan to create more audio', 'speechkit')) {
    $post_status = Speechkit_Admin::STATUS_PAYMENT_REQUIRED;
    update_post_meta(get_the_ID(), 'speechkit_status', $post_status);
}

if ($post_status) {
    ?>
    <!-- Header -->
    <p id="speechkit_status" data-status="<?php echo esc_attr($post_status); ?>">
        <?php _e('Status', 'speechkit'); ?>:
        <b>
            <?php
            switch ($post_status) {
                case Speechkit_Admin::STATUS_NEW:
                case Speechkit_Admin::STATUS_UPDATED:
                case Speechkit_Admin::STATUS_PROCESSING:
                    _e('Processing', 'speechkit');
                    break;
                case Speechkit_Admin::STATUS_PROCESSED:
                case Speechkit_Admin::STATUS_SCHEDULED: // deprecated in v2.9.5
                    _e('Processed', 'speechkit');
                    break;
                case Speechkit_Admin::STATUS_ERROR:
                    echo '<span class="wp-ui-text-notification">' . __('Error', 'speechkit') . '</span>';
                    break;
                case Speechkit_Admin::STATUS_FAILED:
                    echo '<span class="wp-ui-text-notification">' . __('Failed', 'speechkit') . '</span>';
                    break;
                case Speechkit_Admin::STATUS_PAYMENT_REQUIRED:
                    echo '<span class="wp-ui-text-notification">' . __('Payment Required', 'speechkit') . '</span>';
                    break;
                default:
                    _e('New', 'speechkit');
                    break;
            }
            ?>
        </b>
    </p>
    <?php
}

switch ($post_status) {

    case Speechkit_Admin::STATUS_NEW:
    case Speechkit_Admin::STATUS_UPDATED:
    case Speechkit_Admin::STATUS_PROCESSING:
        ?>
        <p><?php _e('SpeechKit is currently processing your audio.', 'speechkit'); ?></p>

        <!-- Show/Hide player -->
        <p><?php _e('Press Hide audio player/Show audio player to remove audio from this post.', 'speechkit'); ?></p>
        <button type="button" class="button button-large sk-metabox-button sk_action_button" id="sk_toggle_action" data-action="sk_toggle">
            <?php

            $is_disabled = 1 == get_post_meta(get_the_ID(), 'speechkit_disabled', true);

            if ($is_disabled) {
                _e('Show Audio Player', 'speechkit');
            } else {
                _e('Hide Audio Player', 'speechkit');
            }

            ?>
        </button>

        <?php
        break;

    case Speechkit_Admin::STATUS_PROCESSED:
    case Speechkit_Admin::STATUS_SCHEDULED: // deprecated in v2.9.5

        $info       = get_post_meta(get_the_ID(), 'speechkit_info', true);
        $audio_link = get_post_meta(get_the_ID(), '_speechkit_link', true);

        if (isset($audio_link)) {
            ?>
            <!-- Listen link -->
            <a href="<?php echo esc_url($audio_link); ?>" target="_blank" class="button button-large sk-metabox-button">
                <?php _e('Listen / Download', 'speechkit'); ?>
            </a>
            <p style="margin-top: 0.5em;">
                <?php _e('Audio for posts with a future publish date is currently unavailable.', 'speechkit'); ?>
                <em>
                    <?php _e('We’re working on this!', 'speechkit'); ?>
                </em>
            </p>
            <hr>
            <?php
        }
        ?>

        <!-- Show/Hide player -->
        <p>
            <?php _e('Press Hide audio player/Show audio player to remove audio from this post.', 'speechkit'); ?>
        </p>

        <button type="button" class="button button-large sk-metabox-button sk_action_button" id="sk_toggle_action" data-action="sk_toggle">
            <?php

            $is_disabled = 1 == get_post_meta(get_the_ID(), 'speechkit_disabled', true);

            if ($is_disabled) {
                _e('Show Audio Player', 'speechkit');
            } else {
                _e('Hide Audio Player', 'speechkit');
            }

            ?>
        </button>

        <hr>

        <!-- Update/regenerate -->
        <p>
            <?php _e('Audio will generate automatically. But you can press “Update Audio” to regenerate manually.', 'speechkit'); ?>
        </p>

        <button type="button" class="button button-large sk-metabox-button sk_action_button" id="sk_regenerate_action" data-action="sk_regenerate">
            <?php _e('Update Audio', 'speechkit'); ?>
        </button>

        <?php
        break;

    case Speechkit_Admin::STATUS_FAILED:
    case Speechkit_Admin::STATUS_ERROR:
        ?>

        <p class="wp-ui-text-notification">
            <?php _e('Sorry, an unknown error prevented us from generating the audio.', 'speechkit'); ?>
        </p>

        <!-- Update/regenerate -->
        <button type="button" class="button button-large sk-metabox-button sk_action_button" id="sk_regenerate_action" data-action="sk_regenerate">
            <?php _e('Try Again', 'speechkit'); ?>
        </button>

        <?php
        break;

    case Speechkit_Admin::STATUS_PAYMENT_REQUIRED:
        // hotfix 2.9.5: if Payment is required then stop processing (resending) the post
        delete_post_meta(get_the_ID(), 'publish_post_to_speechkit');
        delete_post_meta(get_the_ID(), 'speechkit_req_create');
        delete_post_meta(get_the_ID(), 'speechkit_req_update');
        delete_post_meta(get_the_ID(), 'speechkit_retries');
        ?>

        <!-- Update/regenerate -->
        <p class="wp-ui-text-notification">
            <?php _e('A SpeechKit account with available credits is required to generate audio.', 'speechkit'); ?>
        </p>

        <p>
            <?php _e('Please <a href="https://my.speechkit.io/" target="_blank">choose a plan</a> and try again.', 'speechkit'); ?>
        </p>

        <button type="button" class="button button-large sk-metabox-button sk_action_button" id="sk_regenerate_action" data-action="sk_regenerate">
            <?php _e('Try Again', 'speechkit'); ?>
        </button>

        <?php
        break;

    default:
        // The "Generate Audio" WordPress Custom Field (post_meta table in the db)
        $meta_publish_post_to_speechkit = get_post_meta(get_the_ID(), 'publish_post_to_speechkit', true);

        switch ($meta_publish_post_to_speechkit) {
            // The Post has previously been saved with "Generate Audio" CHECKED
            case '1':
                $publish_post_to_speechkit = true;
                break;

            // The Post has previously been saved with "Generate Audio" UNCHECKED
            case '0':
                $publish_post_to_speechkit = false;
                break;

            // The Post does not yet have a "Generate Audio" value in the db
            default:
                $categories = Speechkit_Admin::get_setting('speechkit_selected_categories');

                // Only CHECK the "Generate Audio" checkbox if "All Categories" (the default) is selected
                if ($categories === array('-1')) {
                    $publish_post_to_speechkit = true;
                } else {
                    $publish_post_to_speechkit = false;
                }
                break;
        }
        ?>

        <p>
            <?php _e('SpeechKit will produce audio once you publish your post.', 'speechkit'); ?>
        </p>

        <!-- Generate podcast -->
        <p>
            <input type="checkbox" id="publish_post_to_speechkit" name="publish_post_to_speechkit" <?php checked($publish_post_to_speechkit, '1'); ?> value="1" /> <?php _e('Generate audio', 'speechkit'); ?>
        </p>

        <?php
        break;

}
?>

<hr />

<p>
    <?php _e('Having trouble? Visit our support page or email us at: <a href="mailto:support@speechkit.io">support@speechkit.io</a>', 'speechkit'); ?>
</p>
